#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-orphans
version:              1.0.1
visibility:           public
id:                   binary-orphans-1.0.1-7ajmqklgFuf74UQpmh0JU2
key:                  binary-orphans-1.0.1-7ajmqklgFuf74UQpmh0JU2
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  ec6ced904d9e2d48c8c65e9d67483be0
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-8.10.5/site-local/binary-orphans-1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/binary-orphans-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/binary-orphans-1.0.1
hs-libraries:         HSbinary-orphans-1.0.1-7ajmqklgFuf74UQpmh0JU2
depends:              base-4.14.2.0 binary-0.8.8.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

